#include "lcd.h"
#include <delays.h>
#include "GameGirl.h"
#include "font_5x7.h"		//librairie de caracres pour notre afficheur


void LCD_Init (void)
{	LCD_CSA = 1;			//selectionne les deux contrleurs.		
	LCD_CSB = 1;
	LCD_ENABLE = 0;			//desactive la broche enable
	LCD_RESET = 0;			//met le reset a 0
	Delay100TCYx(1);		//et attend 100 cycles
	LCD_RESET = 1;			//puis met le reset a 1
	LCD_Clear();			//efface l'ecranc
	LCD_Write_Command(0x3F);//active l'affichage sur l'cranc LCD
}

void LCD_Write_Command (unsigned char Data)
{	LCD_RS = 0;				//mode instruction
	LCD_RW = 0;				//mode criture
	LCD_DATA = Data;		//positionne la donne sur le port
	Delay100TCYx(2);		//attend 200 cycles
	LCD_ENABLE = 1;			//active la lecture par l'afficheur
	Delay100TCYx(2);		//attend 200 cycles
	LCD_ENABLE = 0;			//desactive la lecture par l'afficheur
}

void LCD_Send_Data (unsigned char Data)
{	LCD_RS = 1;				//mode donne
	LCD_RW = 0;				//mode ecriture
	LCD_DATA = Data;		//positione la donne sur le port
	Delay100TCYx(2);		//attend 200 cycles
	LCD_ENABLE = 1;			//active la lecture par l'afficheur
	Delay100TCYx(2);		//attend 200 cycles
	LCD_ENABLE = 0;			//desactive la lecture par l'afficheur

}

void LCD_Clear (void)
{	unsigned char i,j;
	LCD_CSA = 1;		//selection des deux contrleurs
	LCD_CSB = 1;
	LCD_Write_Command(0xB8);		//selectionne la ligne 0
	
	for	(i=0 ; i<9 ; i++)			//pour les 8 lignes
	{	for(j=0 ; j<64 ;j++)		//sur les 64 colones
			LCD_Send_Data(0x00);	//envoyer 8 bits de blanc
		LCD_Write_Command((0xB8+i));//selectionner la ligne suivante
	}

}

void LCD_GotoXY (unsigned char X, unsigned char Y)
{	if (X<64) 		//si on se situe sur la page B (gauche)
	{	LCD_CSA = 0;		//selection controleur B
		LCD_CSB = 1;		//page de gauche
		LCD_Write_Command((0xB8+Y));		//place le curseur sur la ligne 0+Y
		LCD_Write_Command((0x40+X));		//place le curseur sur la colone 0+X
	}
	else			//sinon on est sur la page A (droite)
	{	LCD_CSA = 1;		//selection controleur A
		LCD_CSB = 0;		//page de droite (64 colonne plus loin)
		LCD_Write_Command((0xB8+Y));		//place le curseur sur la ligne Y
		LCD_Write_Command((0x40+X-64));		//place le curseur sur la colone X-64

	}
}

void LCD_PutChar (char ch)
{	unsigned char i;
	unsigned int aff;		//variable qui va contenir la premiere valeur du tableau
	aff = ((int)ch-32)*5;	//a afficher ( CF Font_5x7.h )
	for (i=0; i<5; i++)				//afficher les 5 valeurs succsives
	{	LCD_Send_Data(Font[aff+i]);	//pour le caractere demand.
	}
	LCD_Send_Data(0);		//afficher un espace apres le caracre ( pour les mots ).
}

unsigned char LCD_ReadData (void)
{	unsigned char RD;	//variable Read Data
	TRISD = 0b11111111;	//configure le port D en entre
	LCD_RS = LCD_RW = 1;//configure en lecture de donne
	LCD_ENABLE = 1;		//enable a 1 pour signifie ordre stable
	Delay10TCYx(5);		//on attend 50cycles
	LCD_ENABLE = 0;		//enable a 0 pour lancer la lecture
	RD = PORTD;			//on lit la donne sur le port D
	TRISD = 0b00000000;	//configure le port D en sortie
	return RD;
}

void LCD_PutPixel (unsigned char X, unsigned char Y)
{
	unsigned char Val, page=Y>>3;	//Calcule la page courante (ligne)
	LCD_GotoXY (X,page);			//Place le curseur sur l'octet courant
	Val=LCD_ReadData();				//Lit l'octet courant
	Val=LCD_ReadData();				//????? BUG ?????
	
	Val= Val | (0x01 << (Y & 0x07 ));
	//(Y & 0x07) est equivalent au nurmo du bit a mettre a 1 (0 a 7)
	//0x80 >> (Y & 0x07 ) est equivalent a l'octet contenant le bit a mettre a 1
	//exemple : si VAl = 0100 1010 et Y = 0001 0100 (18 donc page 2, bit 2)
	//on fait Val = 1010 1000 | (1000 0000 >> 0000 0010) = 1010 1010 

	LCD_GotoXY (X,page);			//replace le curseur
	LCD_Send_Data(Val);				//envoie la donne transforme
}
